@@ -16,8 +16,13 @@
  *
  */
 
+/*
+   Use the copy of the struct burn_source definition in libisofs.h
+*/
+#define LIBISOFS_WITHOUT_LIBBURN yes
+#include "libisofs.h"
+
 #include "buffer.h"
-#include "libburn/libburn.h"
 #include "ecma119.h"
 
 #include <pthread.h>
