@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
+ * Copyright (c) 2009 Thomas Schmitt
  * 
  * This file is part of the libisofs project; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License version 2 as 
@@ -12,6 +13,7 @@
 
 #include "fsource.h"
 #include "util.h"
+#include "aaip_0_2.h"
 
 #include <stdlib.h>
 #include <sys/types.h>
@@ -32,6 +34,7 @@ int iso_file_source_new_lfs(IsoFileSource *parent, const char *name,
  */
 IsoFilesystem *lfs= NULL;
 
+
 typedef struct
 {
     /** reference to the parent (if root it points to itself) */
@@ -466,8 +469,60 @@ void lfs_free(IsoFileSource *src)
     iso_filesystem_unref(lfs);
 }
 
+
+static 
+int lfs_get_aa_string(IsoFileSource *src, unsigned char **aa_string, int flag)
+{
+    int ret;
+    size_t num_attrs = 0, *value_lengths = NULL, result_len, sret;
+    char *path = NULL, **names = NULL, **values = NULL;
+    unsigned char *result = NULL;
+    _LocalFsFileSource *data;
+
+    data = src->data;
+
+    *aa_string = NULL;
+
+    if ((flag & 3 ) == 3) {
+        ret = 1;
+        goto ex;
+    }
+    /* Obtain EAs and ACLs ("access" and "default"). ACLs encoded according
+       to AAIP ACL representation. Clean out st_mode ACL entries.
+    */ 
+    path = iso_file_source_get_path(src);
+    ret = aaip_get_attr_list(path, &num_attrs, &names,
+                             &value_lengths, &values,
+                             (!(flag & 2)) | 2 | (flag & 4) | 16);
+    if (ret <= 0) {
+        ret = ISO_FILE_ERROR;
+        goto ex;
+    }
+    if (num_attrs == 0)
+        result = NULL;
+    else {
+        sret = aaip_encode(num_attrs, names,
+                           value_lengths, values, &result_len, &result, 0);
+        if (sret == 0) {
+            ret = ISO_OUT_OF_MEM;
+            goto ex;
+         }
+    }
+    *aa_string = result;
+    ret = 1;
+ex:;
+    if (path != NULL)
+        free(path);
+    if (names != NULL || value_lengths != NULL || values != NULL)
+        aaip_get_attr_list(path, &num_attrs, &names, &value_lengths, &values,
+                           1 << 15); /* free memory */
+    return ret;
+}
+
+
 IsoFileSourceIface lfs_class = { 
-    0, /* version */
+
+    1, /* version */
     lfs_get_path,
     lfs_get_name,
     lfs_lstat,
@@ -480,9 +535,12 @@ IsoFileSourceIface lfs_class = {
     lfs_readlink,
     lfs_get_filesystem,
     lfs_free,
-    lfs_lseek
+    lfs_lseek,
+    lfs_get_aa_string
+
 };
 
+
 /**
  * 
  * @return
@@ -690,3 +748,78 @@ int iso_local_filesystem_new(IsoFilesystem **fs)
     *fs = lfs;
     return ISO_SUCCESS;
 }
+
+
+int iso_local_get_acl_text(char *disk_path, char **text, int flag)
+{
+    int ret;
+
+    ret = aaip_get_acl_text(disk_path, text, flag & (1 | 16 | 32 | (1 << 15)));
+    return ret;
+}
+
+
+int iso_local_set_acl_text(char *disk_path, char *text, int flag)
+{
+    int ret;
+
+    ret = aaip_set_acl_text(disk_path, text, flag & (1 | 32));
+    if (ret < 0)
+        return ISO_AAIP_NO_SET_LOCAL;
+    return ret;
+}
+
+
+int iso_local_get_attrs(char *disk_path, size_t *num_attrs, char ***names,
+                        size_t **value_lengths, char ***values, int flag)
+{
+    int ret;
+
+    ret = aaip_get_attr_list(disk_path,
+                             num_attrs, names, value_lengths, values,
+                             (flag & (1 | 4 | 8 | 32 | (1 << 15))) | 2 | 16);
+    if (ret <= 0)
+        return ISO_AAIP_NO_GET_LOCAL;
+    return 1;
+}
+
+
+int iso_local_set_attrs(char *disk_path, size_t num_attrs, char **names,
+                        size_t *value_lengths, char **values, int flag)
+{
+    int ret;
+
+    ret = aaip_set_attr_list(disk_path, num_attrs, names, value_lengths,
+                             values, (flag & (8 | 32)) | !(flag & 1));
+    if (ret <= 0) {
+        if (ret == -1)
+            return ISO_OUT_OF_MEM;
+        if (ret == -2)
+            return ISO_AAIP_BAD_AASTRING;
+        return ISO_AAIP_NO_SET_LOCAL;
+    }
+    return 1;
+}
+
+
+int iso_local_get_perms_wo_acl(char *disk_path, mode_t *st_mode, int flag)
+{
+    struct stat stbuf;
+    int ret;
+    char *a_text = NULL;
+
+    if (flag & 32)
+        ret = stat(disk_path, &stbuf);
+    else
+        ret = lstat(disk_path, &stbuf);
+    if (ret == -1)
+        return -1;
+    *st_mode = stbuf.st_mode & (S_IRWXU | S_IRWXG | S_IRWXO);
+    ret = iso_local_get_acl_text(disk_path, &a_text, 16 | (flag & 32));
+    if (a_text != NULL) {
+        aaip_cleanout_st_mode(a_text, st_mode, 4 | 16);
+        iso_local_get_acl_text(disk_path, &a_text, 1 << 15); /* free a_text */
+    }
+    return 1;
+}
+
