@@ -15,6 +15,9 @@
 #include "libisofs.h"
 #include "messages.h"
 
+#include "util.h"
+
+
 /*
  * error codes are 32 bit numbers, that follow the following conventions:
  *
@@ -55,8 +58,19 @@ int abort_threshold = LIBISO_MSGS_SEV_FAILURE;
 
 struct libiso_msgs *libiso_msgr = NULL;
 
-int iso_init()
+
+/*
+  @param flag  bit0= do not set up locale by LC_* environment variables
+*/
+int iso_init_with_flag(int flag)
 {
+
+#ifdef Libisofs_setlocale_in_iniT
+    if (! (flag & 1)) {
+        iso_init_locale(0);
+    }
+#endif
+
     if (libiso_msgr == NULL) {
         if (libiso_msgs_new(&libiso_msgr, 0) <= 0)
             return ISO_FATAL_ERROR;
@@ -66,6 +80,12 @@ int iso_init()
     return 1;
 }
 
+
+int iso_init()
+{
+    return iso_init_with_flag(0);
+}
+
 void iso_finish()
 {
     libiso_msgs_destroy(&libiso_msgr, 0);
@@ -227,6 +247,22 @@ const char *iso_error_to_msg(int errcode)
         return "Error with attaching ACL or xattr to local file";
     case ISO_AAIP_NON_USER_NAME:
         return "Unallowed attempt to set an xattr with non-userspace name";
+    case ISO_EXTF_TOO_OFTEN:
+        return "Too many references on a single external filter command";
+    case ISO_ZLIB_NOT_ENABLED:
+        return "Use of zlib was not enabled at compile time";
+    case ISO_ZISOFS_TOO_LARGE:
+        return "Cannot apply zisofs filter to file >= 4 GiB";
+    case ISO_FILTER_WRONG_INPUT:
+        return "Filter input differs from previous run";
+    case ISO_ZLIB_COMPR_ERR:
+        return "zlib compression/decompression error";
+    case ISO_ZISOFS_WRONG_INPUT:
+        return "Input stream is not in zisofs format";
+    case ISO_ZISOFS_PARAM_LOCK:
+        return "Cannot set global zisofs parameters while filters exist";
+    case ISO_ZLIB_EARLY_EOF:
+        return "Premature EOF of zlib input stream";
     default:
         return "Unknown error";
     }
