@@ -11,6 +11,8 @@
 #include "node.h"
 #include "stream.h"
 #include "aaip_0_2.h"
+#include "messages.h"
+
 
 #include <stdlib.h>
 #include <string.h>
@@ -1372,10 +1374,9 @@ int attrs_cleanout_name(char *del_name, size_t *num_attrs, char **names,
 
 /**
  * Backend of iso_node_get_attrs() with parameter node replaced by the
- * AA string from where to get the attribute list.
+ * AAIP string from where to get the attribute list.
  * All other parameter specs apply.
  */
-static
 int iso_aa_get_attrs(unsigned char *aa_string, size_t *num_attrs,
               char ***names, size_t **value_lengths, char ***values, int flag)
 {
@@ -1447,6 +1448,62 @@ ex:;
 }
 
 
+/**
+ * Search given name. Eventually calloc() and copy value. Add trailing 0 byte
+ * for caller convenience.
+ *
+ * @return 1= found , 0= not found , <0 error
+ */
+int iso_aa_lookup_attr(unsigned char *aa_string, char *name,
+                       size_t *value_length, char **value, int flag)
+{
+    size_t num_attrs = 0, *value_lengths = NULL;
+    char **names = NULL, **values = NULL;
+    int i, ret = 0, found = 0;
+
+    ret = iso_aa_get_attrs(aa_string, &num_attrs, &names,
+                           &value_lengths, &values, 0);
+    for (i = 0; i < num_attrs; i++) {
+        if (strcmp(names[i], name))
+    continue;
+        *value_length = value_lengths[i];
+        *value = calloc(*value_length + 1, 1);
+        if (*value == NULL) {
+            ret = ISO_OUT_OF_MEM;
+    break;
+        }
+        if (*value_length > 0)
+            memcpy(*value, values[i], *value_length);
+        (*value)[*value_length] = 0;
+        found = 1;
+    break;
+    }
+    iso_aa_get_attrs(aa_string, &num_attrs, &names,
+                     &value_lengths, &values, 1 << 15);
+    return found;
+}
+
+
+/* API */
+int iso_node_lookup_attr(IsoNode *node, char *name,
+                         size_t *value_length, char **value, int flag)
+{
+    void *xipt;
+    unsigned char *aa_string = NULL;
+    int ret;
+
+    *value_length= 0;
+    *value= NULL;
+    ret = iso_node_get_xinfo(node, aaip_xinfo_func, &xipt);
+    if (ret != 1)
+        return 0;
+    aa_string = (unsigned char *) xipt;
+    ret = iso_aa_lookup_attr(aa_string, name, value_length, value, 0);
+    return ret;
+}
+
+
+/* API */
 int iso_node_get_attrs(IsoNode *node, size_t *num_attrs,
               char ***names, size_t **value_lengths, char ***values, int flag)
 {
@@ -2058,3 +2115,127 @@ ex:;
     return st_mode;
 }
 
+
+/* Function to identify and manage ZF parameters.
+ * data is supposed to be a pointer to struct zisofs_zf_info
+ */
+int zisofs_zf_xinfo_func(void *data, int flag)
+{
+    if (flag & 1) {
+        free(data);
+    }
+    return 1;
+}
+
+
+/* Checks whether a file effectively bears a zisofs file header and eventually
+ * marks this by a struct zisofs_zf_info as xinfo of the file node.
+ * @param flag bit0= inquire the most original stream of the file
+ *             bit1= permission to overwrite existing zisofs_zf_info
+ *             bit2= if no zisofs header is found:
+ *                   create xinfo with parameters which indicate no zisofs
+ * @return 1= zf xinfo added, 0= no zisofs data found ,
+ *         2= found existing zf xinfo and flag bit1 was not set
+ *         <0 means error
+ */
+int iso_file_zf_by_magic(IsoFile *file, int flag)
+{
+    int ret, stream_type, header_size_div4, block_size_log2;
+    uint32_t uncompressed_size;
+    IsoStream *stream, *input_stream;
+    struct zisofs_zf_info *zf = NULL;
+    void *xipt;
+
+    /* Intimate friendship with this function in filters/zisofs.c */
+    int ziso_is_zisofs_stream(IsoStream *stream, int *stream_type,
+                              int *header_size_div4, int *block_size_log2,
+                              uint32_t *uncompressed_size, int flag);
+
+    ret = iso_node_get_xinfo((IsoNode *) file, zisofs_zf_xinfo_func, &xipt);
+    if (ret == 1) {
+        if (!(flag & 2))
+            return 2;
+        ret = iso_node_remove_xinfo((IsoNode *) file, zisofs_zf_xinfo_func);
+        if (ret < 0)
+            return ret;
+    }
+    input_stream = stream = iso_file_get_stream(file);
+    while (flag & 1) {
+        input_stream = iso_stream_get_input_stream(stream, 0);
+        if (input_stream == NULL)
+    break;
+        stream = input_stream;
+    }
+    ret = ziso_is_zisofs_stream(stream, &stream_type, &header_size_div4,
+                                &block_size_log2, &uncompressed_size, 3);
+    if (ret < 0)
+        return ret;
+    if (ret != 1 || stream_type != 2) {
+        if (flag & 4)
+            return 0;
+        header_size_div4 = 0;
+        block_size_log2 = 0;
+        uncompressed_size = 0;
+    }
+    zf = calloc(1, sizeof(struct zisofs_zf_info));
+    if (zf == NULL)
+        return ISO_OUT_OF_MEM;
+    zf->uncompressed_size = uncompressed_size;
+    zf->header_size_div4 = header_size_div4;
+    zf->block_size_log2 = block_size_log2;
+    ret = iso_node_add_xinfo((IsoNode *) file, zisofs_zf_xinfo_func, zf);
+    return ret;
+}
+
+
+/* API */
+int iso_node_zf_by_magic(IsoNode *node, int flag)
+{
+    int ret = 1, total_ret = 0, hflag;
+    IsoFile *file;
+    IsoNode *pos;
+    IsoDir *dir;
+
+    if (node->type == LIBISO_FILE)
+        return iso_file_zf_by_magic((IsoFile *) node, flag);
+    if (node->type != LIBISO_DIR || (flag & 8))
+        return 0;
+
+    dir = (IsoDir *) node;
+    pos = dir->children;
+    while (pos) {
+        ret = 1;
+        if (pos->type == LIBISO_FILE) {
+            file = (IsoFile *) pos;
+            if ((flag & 16) && file->from_old_session)
+                return 0;
+            if (!((flag & 1) && file->from_old_session)) {
+                if (strncmp(file->stream->class->type, "ziso", 4) == 0)
+                    return 1; /* The stream is enough of marking */
+                if (strncmp(file->stream->class->type, "osiz", 4) == 0) {
+                    if (flag & 2)
+                        iso_node_remove_xinfo(pos, zisofs_zf_xinfo_func);
+                    return 0; /* Will not be zisofs format */
+                }
+            }
+            hflag = flag & ~6;
+            if ((flag & 1) && file->from_old_session)
+                hflag |= 1;
+            ret = iso_file_zf_by_magic(file, hflag);
+        } else if (pos->type == LIBISO_DIR) {
+            ret = iso_node_zf_by_magic(pos, flag);
+        }
+        if (ret < 0) {
+            total_ret = ret;
+            ret = iso_msg_submit(-1, ret, 0, NULL);
+            if (ret < 0) {
+                return ret; /* cancel due error threshold */
+            }
+        } else if (total_ret >= 0) {
+            total_ret |= ret;
+        }
+        pos = pos->next;
+    }
+    return total_ret;
+}
+
