@@ -15,6 +15,7 @@
 #include "messages.h"
 #include "image.h"
 #include "aaip_0_2.h"
+#include "libisofs.h"
 
 #include <string.h>
 
@@ -384,7 +385,6 @@ int rrip_SL_append_comp(size_t *n, uint8_t ***comps, char *s, int size, char fl)
 
 #ifdef Libisofs_with_rrip_rR
 
-/* ts A90307 */
 /**
  * Add to the given tree node a RR System Use Entry. This is an obsolete 
  * entry from before RRIP-1.10. Nevertheless mkisofs produces it and there
@@ -505,7 +505,7 @@ int rrip_add_SL(Ecma119Image *t, struct susp_info *susp, uint8_t **comp,
                      parameters susp and data may be NULL in this case
 */
 static
-int aaip_add_AA(Ecma119Image *t, struct susp_info *susp,
+int aaip_add_AL(Ecma119Image *t, struct susp_info *susp,
                 uint8_t **data, size_t num_data,
                 size_t *sua_free, size_t *ce_len, int flag)
 {
@@ -647,45 +647,46 @@ int rrip_add_ER(Ecma119Image *t, struct susp_info *susp)
 static
 int aaip_add_ER(Ecma119Image *t, struct susp_info *susp, int flag)
 {
-    unsigned char *AA;
+    unsigned char *ER;
 
-    AA = malloc(160);
-    if (AA == NULL) {
+    ER = malloc(160);
+    if (ER == NULL) {
         return ISO_OUT_OF_MEM;
     }
     
-    AA[0] = 'E';
-    AA[1] = 'R';
-    AA[2] = 160;
-    AA[3] = 1;
-    AA[4] = 9;
-    AA[5] = 81;
-    AA[6] = 62;
-    AA[7] = 1;
+    ER[0] = 'E';
+    ER[1] = 'R';
+    ER[2] = 160;
+    ER[3] = 1;
+    ER[4] = 9;
+    ER[5] = 81;
+    ER[6] = 62;
+    ER[7] = 1;
 
-#define Libisofs_aaip_1_0 yes
-#ifdef Libisofs_aaip_1_0
+#ifdef Libisofs_aaip_2_0
 
-    memcpy(AA + 8, "AAIP_0100", 9);
-    memcpy(AA + 17,
-           "AA PROVIDES VIA AAIP 1.0 SUPPORT FOR ARBITRARY FILE ATTRIBUTES"
+    memcpy(ER + 8, "AAIP_0200", 9);
+    memcpy(ER + 17,
+           "AL PROVIDES VIA AAIP 2.0 SUPPORT FOR ARBITRARY FILE ATTRIBUTES"
            " IN ISO 9660 IMAGES", 81);
-
-#else /* Libisofs_aaip_1_0 */
-
-    memcpy(AA + 8, "AAIP_0002", 9);
-    memcpy(AA + 17,
-           "AA PROVIDES VIA AAIP 0.2 SUPPORT FOR ARBITRARY FILE ATTRIBUTES"
-           " IN ISO 9660 IMAGES", 81);
-
-#endif /* ! Libisofs_aaip_1_0 */
-
-    memcpy(AA + 98,
+    memcpy(ER + 98,
            "PLEASE CONTACT THE LIBBURNIA PROJECT VIA LIBBURNIA-PROJECT.ORG",
            62);
 
+#else /* Libisofs_aaip_2_0 */
+
+    memcpy(ER + 8, "AAIP_0100", 9);
+    memcpy(ER + 17,
+           "AA PROVIDES VIA AAIP 1.0 SUPPORT FOR ARBITRARY FILE ATTRIBUTES"
+           " IN ISO 9660 IMAGES", 81);
+    memcpy(ER + 98,
+           "PLEASE CONTACT THE LIBBURNIA PROJECT VIA LIBBURNIA-PROJECT.ORG",
+           62);
+
+#endif /* ! Libisofs_aaip_2_0 */
+
     /** This always goes to continuation area */
-    return susp_append_ce(t, susp, AA);
+    return susp_append_ce(t, susp, ER);
 }
 
 
@@ -765,6 +766,145 @@ int susp_add_ES(Ecma119Image *t, struct susp_info *susp, int to_ce, int seqno)
 }
 
 
+/**
+ * see doc/zisofs_format.txt : "ZF System Use Entry Format"
+ */
+static
+int zisofs_add_ZF(Ecma119Image *t, struct susp_info *susp, int to_ce,
+                  int header_size_div4, int block_size_log2,
+                  uint32_t uncompressed_size, int flag)
+{
+    unsigned char *ZF = malloc(16);
+
+    if (ZF == NULL) {
+        return ISO_OUT_OF_MEM;
+    }
+    ZF[0] = 'Z';
+    ZF[1] = 'F';
+    ZF[2] = (unsigned char) 16;
+    ZF[3] = (unsigned char) 1;
+    ZF[4] = (unsigned char) 'p';
+    ZF[5] = (unsigned char) 'z';
+    ZF[6] = (unsigned char) header_size_div4;
+    ZF[7] = (unsigned char) block_size_log2;
+    iso_bb(&ZF[8], uncompressed_size, 4);
+    if (to_ce) {
+        return susp_append_ce(t, susp, ZF);
+    } else {
+        return susp_append(t, susp, ZF);
+    }
+}
+
+
+/* @param flag bit0= Do not add data but only count sua_free and ce_len
+*/
+static
+int add_zf_field(Ecma119Image *t, Ecma119Node *n, struct susp_info *info,
+                 size_t *sua_free, size_t *ce_len, int flag)
+{
+    int ret, will_copy = 1, stream_type = 0, do_zf = 0;
+    int header_size_div4 = 0, block_size_log2 = 0;
+    uint32_t uncompressed_size = 0;
+    IsoStream *stream = NULL, *input_stream, *last_stream, *first_stream;
+    IsoStream *first_filter = NULL;
+    IsoFile *file;
+    void *xipt;
+    struct zisofs_zf_info *zf;
+
+    /* Intimate friendship with this function in filters/zisofs.c */
+    int ziso_is_zisofs_stream(IsoStream *stream, int *stream_type,
+                              int *header_size_div4, int *block_size_log2,
+                              uint32_t *uncompressed_size, int flag);
+
+
+    if (iso_node_get_type(n->node) != LIBISO_FILE)
+        return 2;
+    file = (IsoFile *) n->node;
+
+    /* Inspect: last_stream < ... < first_filter < first_stream */
+    /* The content is in zisofs format if:
+       It gets copied and
+           the last stream is a ziso stream,
+           or it had a ZF entry and is unfiltered
+           or it has a zf xinfo record (because its last stream delivered a
+                                        zisofs file header when inquired)
+       or it stays uncopied and
+           the first filter is an osiz stream,
+           or it had a ZF entry
+           or it has a zf xinfo record (because its first stream delivered a 
+                                        zisofs file header when inquired)
+    */
+
+    if (t->appendable && file->from_old_session) 
+        will_copy = 0;
+
+    first_filter = first_stream = last_stream = iso_file_get_stream(file);
+    while (1) {
+        input_stream = iso_stream_get_input_stream(first_stream, 0);
+        if (input_stream == NULL)
+    break;
+        first_filter = first_stream;
+        first_stream = input_stream;
+    }
+    if (will_copy) {
+        stream = last_stream;
+    } else {
+        /* (the eventual osiz filter on the image stream) */
+        stream = first_filter;
+    }
+
+    /* Determine stream type : 1=ziso , -1=osiz , 0=other */
+    ret = ziso_is_zisofs_stream(stream, &stream_type, &header_size_div4,
+                                &block_size_log2, &uncompressed_size, 0);
+    if (ret < 0)
+        return ret;
+
+    if (stream_type == 1 && will_copy) {
+        do_zf = 1;
+    } else if (stream_type == -1 && !will_copy) {
+        do_zf = 1;
+    } else if(first_stream == last_stream || !will_copy) {
+        /* Try whether the image side stream remembers a ZF field */
+        ret = iso_stream_get_src_zf(first_stream, &header_size_div4,
+                                    &block_size_log2, &uncompressed_size, 0);
+        if (ret == 1 && header_size_div4 > 0)
+            do_zf = 1;
+    }
+    if (!do_zf) {
+        /* Look for an xinfo mark of a zisofs header */
+        ret = iso_node_get_xinfo((IsoNode *) file, zisofs_zf_xinfo_func,
+                                 &xipt);
+        if (ret == 1) {
+            zf = xipt;
+            header_size_div4 = zf->header_size_div4;
+            block_size_log2 = zf->block_size_log2;
+            uncompressed_size = zf->uncompressed_size;
+            if (header_size_div4 > 0)
+                do_zf = 1;
+        }
+    }
+
+    if (!do_zf)
+        return 2;
+
+    /* Account for field size */
+    if (*sua_free < 16 || *ce_len > 0) {
+        *ce_len += 16;
+    } else {
+        *sua_free -= 16;
+    }
+    if (flag & 1)
+        return 1;
+
+    /* write ZF field */
+    ret = zisofs_add_ZF(t, info, (*ce_len > 0), header_size_div4,
+                       block_size_log2, uncompressed_size, 0);
+    if (ret < 0)
+        return ret;
+    return 1;
+}
+
+
 int aaip_xinfo_func(void *data, int flag)
 {
     if (flag & 1) {
@@ -775,8 +915,8 @@ int aaip_xinfo_func(void *data, int flag)
 
 
 /**
- * Compute SUA lentgth and eventual Continuation Area length of field NM and
- * eventually fields SL and AA. Because CA usage makes necessary the use of
+ * Compute SUA length and eventual Continuation Area length of field NM and
+ * eventually fields SL and AL. Because CA usage makes necessary the use of
  * a CE entry of 28 bytes in SUA, this computation fails if not the 28 bytes
  * are taken into account at start. In this case the caller should retry with
  * bit0 set. 
@@ -789,7 +929,7 @@ int aaip_xinfo_func(void *data, int flag)
  *                 -1= not enough SUA space for 28 bytes of CE entry
  */
 static
-int susp_calc_nm_sl_aa(Ecma119Image *t, Ecma119Node *n, size_t space,
+int susp_calc_nm_sl_al(Ecma119Image *t, Ecma119Node *n, size_t space,
                        size_t *su_size, size_t *ce, int flag)
 {
     char *name;
@@ -930,23 +1070,31 @@ int susp_calc_nm_sl_aa(Ecma119Image *t, Ecma119Node *n, size_t space,
 
     }
 
+    /* Find out whether ZF is to be added and account for its bytes */
+    sua_free = space - *su_size;
+    add_zf_field(t, n, NULL, &sua_free, ce, 1);
+    *su_size = space - sua_free;
+    if (*ce > 0 && !(flag & 1))
+        goto unannounced_ca;
+
     /* obtain num_aapt from node */
     xipt = NULL;
     num_aapt = 0;
     if (t->aaip) {
         ret = iso_node_get_xinfo(n->node, aaip_xinfo_func, &xipt);
         if (ret == 1) {
-           num_aapt = aaip_count_bytes((unsigned char *) xipt, 0);
+            num_aapt = aaip_count_bytes((unsigned char *) xipt, 0);
         }
     }
     /* let the expert decide where to add num_aapt */
     if (num_aapt > 0) {
         sua_free = space - *su_size;
-        aaip_add_AA(t, NULL, NULL, num_aapt, &sua_free, ce, 1);
+        aaip_add_AL(t, NULL, NULL, num_aapt, &sua_free, ce, 1);
         *su_size = space - sua_free;
         if (*ce > 0 && !(flag & 1))
             goto unannounced_ca;
     }
+
     return 1;
 
 unannounced_ca:;
@@ -991,7 +1139,7 @@ size_t rrip_calc_len(Ecma119Image *t, Ecma119Node *n, int type, size_t space,
         su_size += 5;
 
 #ifdef Libisofs_with_rrip_rR
-    /* obsolete RR field (once in AAIP-1.09) */
+    /* obsolete RR field (once in RRIP-1.09) */
     su_size += 5;
 #endif
 
@@ -1026,9 +1174,9 @@ size_t rrip_calc_len(Ecma119Image *t, Ecma119Node *n, int type, size_t space,
     if (type == 0) {
 
         /* Try without CE */
-        ret = susp_calc_nm_sl_aa(t, n, space, &su_size, ce, 0);
+        ret = susp_calc_nm_sl_al(t, n, space, &su_size, ce, 0);
         if (ret == 0) /* Retry with CE */
-            susp_calc_nm_sl_aa(t, n, space, &su_size, ce, 1);
+            susp_calc_nm_sl_al(t, n, space, &su_size, ce, 1);
 
     } else {
 
@@ -1043,20 +1191,12 @@ size_t rrip_calc_len(Ecma119Image *t, Ecma119Node *n, int type, size_t space,
              * ER needs a Continuation Area, thus we also need a CE entry
              */
             su_size += 7 + 28; /* SP + CE */
-
-#ifdef Libisofs_rrip_1_10_er_bugfiX
-
             /* ER of RRIP */
             if (t->rrip_version_1_10) {
                 *ce = 237;
             } else {
                 *ce = 182;
             }
-
-#else
-            *ce = 182;
-#endif
-
             if (t->aaip) {
                 *ce += 160; /* ER of AAIP */
             }
@@ -1102,6 +1242,9 @@ int add_aa_string(Ecma119Image *t, Ecma119Node *n, struct susp_info *info,
     void *xipt;
     size_t num_aapt= 0;
 
+    if (!t->aaip)
+        return 1;
+
     ret = iso_node_get_xinfo(n->node, aaip_xinfo_func, &xipt);
     if (ret == 1) {
         num_aapt = aaip_count_bytes((unsigned char *) xipt, 0);
@@ -1110,7 +1253,7 @@ int add_aa_string(Ecma119Image *t, Ecma119Node *n, struct susp_info *info,
             if (aapt == NULL)
                 return ISO_OUT_OF_MEM;
             memcpy(aapt, xipt, num_aapt);
-            ret = aaip_add_AA(t, info, &aapt, num_aapt, sua_free, ce_len,
+            ret = aaip_add_AL(t, info, &aapt, num_aapt, sua_free, ce_len,
                               flag & 1);
             if (ret < 0) 
                 return ret;
@@ -1147,11 +1290,7 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
     char *name = NULL;
     char *dest = NULL;
     size_t aaip_er_len= 0;
-
-#ifdef Libisofs_rrip_1_10_er_bugfiX
     size_t rrip_er_len= 182;
-#endif
-
     size_t su_size_pd, ce_len_pd; /* predicted sizes of SUA and CA */
     int ce_is_predicted = 0;
     size_t aaip_sua_free= 0, aaip_len= 0;
@@ -1196,7 +1335,6 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
     }
 
 #ifdef Libisofs_with_rrip_rR
-    /* ts A90307 */
     ret = rrip_add_RR(t, node, info);
     if (ret < 0) {
         goto add_susp_cleanup;
@@ -1264,12 +1402,12 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
 
         sua_free = space - info->suf_len;
 
-        /* Try whether NM, SL, AA will fit into SUA */
+        /* Try whether NM, SL, AL will fit into SUA */
         su_size_pd = info->suf_len;
         ce_len_pd = ce_len;
-        ret = susp_calc_nm_sl_aa(t, n, space, &su_size_pd, &ce_len_pd, 0);
+        ret = susp_calc_nm_sl_al(t, n, space, &su_size_pd, &ce_len_pd, 0);
         if (ret == 0) { /* Have to use CA. 28 bytes of CE are necessary */
-            susp_calc_nm_sl_aa(t, n, space, &su_size_pd, &ce_len_pd, 1);
+            susp_calc_nm_sl_al(t, n, space, &su_size_pd, &ce_len_pd, 1);
             sua_free -= 28;
             ce_is_predicted = 1;
         }
@@ -1493,16 +1631,18 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
             }
         }
 
-        /* Obtain AA field string from node
+        /* Eventually write zisofs ZF field */
+        ret = add_zf_field(t, n, info, &sua_free, &ce_len, 0);
+        if (ret < 0)
+            goto add_susp_cleanup;
+
+        /* Eventually obtain AAIP field string from node
            and write it to directory entry or CE area.
         */
-        ret = ISO_SUCCESS;
+        ret = add_aa_string(t, n, info, &sua_free, &ce_len, 0);
+        if (ret < 0)
+            goto add_susp_cleanup;
 
-        if (t->aaip) {
-            ret = add_aa_string(t, n, info, &sua_free, &ce_len, 0);
-            if (ret < 0)
-                goto add_susp_cleanup;
-        }
 
     } else {
 
@@ -1522,8 +1662,6 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
              * Note that SP entry was already added above
              */
 
-#ifdef Libisofs_rrip_1_10_er_bugfiX
-
             if (t->rrip_version_1_10) {
                 rrip_er_len = 237;
             } else {
@@ -1541,25 +1679,6 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
 
             /* Allocate the necessary CE space */
             ret = susp_add_CE(t, rrip_er_len + aaip_er_len + aaip_len, info);
-
-#else /* Libisofs_rrip_1_10_er_bugfiX */
-
-            if (t->aaip && !t->aaip_susp_1_10) {
-                aaip_er_len = 160;
-            }
-
-            /* Compute length of AAIP string of root node */
-            aaip_sua_free= 0;
-            ret = add_aa_string(t, n, info, &aaip_sua_free, &aaip_len, 1);
-            if (ret < 0)
-                goto add_susp_cleanup;
-
-            /* Allocate the necessary CE space */
-            ret = susp_add_CE(t, 182 + aaip_er_len + aaip_len, info);
-                                                    /* 182 is RRIP-ER length */
-
-#endif /* ! Libisofs_rrip_1_10_er_bugfiX */
-
             if (ret < 0) {
                 goto add_susp_cleanup;
             }
