@@ -10,18 +10,29 @@
 
 /**
  * This header defines the functions and structures needed to add RockRidge
- * extensions to an ISO image. 
+ * extensions to an ISO image. It also handles AAIP and zisofs extensions.
  * 
  * References:
  * 
  * - SUSP (IEEE 1281).
  * System Use Sharing Protocol, draft standard version 1.12.
+ * See ftp://ftp.ymi.com/pub/rockridge/susp112.ps
  * 
  * - RRIP (IEEE 1282)
  * Rock Ridge Interchange Protocol, Draft Standard version 1.12.
+ * See ftp://ftp.ymi.com/pub/rockridge/rrip112.ps
  * 
  * - ECMA-119 (ISO-9660)
- * Volume and File Structure of CDROM for Information Interchange.
+ * Volume and File Structure of CDROM for Information Interchange. See
+ * http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-119.pdf
+ *
+ * - AAIP
+ * Arbitrary Attribute Interchange Protocol. See doc/susp_aaip_2_0.txt
+ *
+ * - zisofs
+ * Blockwise compression of data file content with transparent read support
+ * in the Linux kernel. See doc/zisofs_format.txt
+ *
  */
 
 #ifndef LIBISO_ROCKRIDGE_H
@@ -118,12 +129,26 @@ struct rr_SL {
 };
 
 
-/** Arbitrary Attribute (AAIP, see doc/susp_aaip_1_0.txt) */
-struct rr_AA {
+/** Outdated Arbitrary Attribute (AAIP, see doc/susp_aaip_1_0.txt)
+ *  It collided with pre-SUSP Apple AA field.
+ */
+struct aaip_AA {
     uint8_t flags[1];
     uint8_t comps[1];
 };
 
+/** Arbitrary Attribute (AAIP, see doc/susp_aaip_2_0.txt) */
+struct aaip_AL {
+    uint8_t flags[1];
+    uint8_t comps[1];
+};
+
+
+/** zisofs entry  (see doc/zisofs_format.txt) */
+struct zisofs_ZF {
+    uint8_t parameters[1]; /* begins with BP 5 */
+};
+
 
 /**
  * Struct for a SUSP System User Entry (SUSP, 4.1)
@@ -143,8 +168,9 @@ struct susp_sys_user_entry
         struct rr_NM NM;
         struct rr_CL CL;
         struct rr_SL SL;
-        struct rr_AA AA;
-
+        struct aaip_AA AA;
+        struct aaip_AL AL;
+        struct zisofs_ZF ZF;
     } data; /* 5 to 4+len_sue */
 };
 
@@ -278,8 +304,8 @@ int read_rr_PN(struct susp_sys_user_entry *pn, struct stat *st);
 
 
 /**
- * Collects the AA field string from single AA fields.
- * (see doc/susp_aaip_0_2.txt)
+ * Collects the AAIP field string from single AAIP fields.
+ * (see doc/susp_aaip_1_0.txt)
  * @param aa_string   Storage location of the emerging string.
  *                    Begin with *aa_string == NULL, or own malloc() storage.
  * @param aa_size     Current allocated size of aa_string.
@@ -288,14 +314,33 @@ int read_rr_PN(struct susp_sys_user_entry *pn, struct stat *st);
  *                    Begin with *aa_len == 0
  * @param prev_field  Returns the index of start of the previous field
  *                    in the string.
- * @param is_done     The current completion state of the AA field string.
+ * @param is_done     The current completion state of the AAIP field string.
  *                    Fields will be ignored as soon as it is 1.
  *                    Begin with *is_done == 0
  * @param flag        Unused yet. Submit 0.
+ * @return 
+ *      1 on success, < 0 on error
  */
 int read_aaip_AA(struct susp_sys_user_entry *sue,
                  unsigned char **aa_string, size_t *aa_size, size_t *aa_len,
                  size_t *prev_field, int *is_done, int flag);
 
+/**
+ * Collects the AAIP field string from single AL fields.
+ * (see doc/susp_aaip_2_0.txt)
+ */
+int read_aaip_AL(struct susp_sys_user_entry *sue,
+                 unsigned char **aa_string, size_t *aa_size, size_t *aa_len,
+                 size_t *prev_field, int *is_done, int flag);
+
+/**
+ * Reads the zisofs parameters from a ZF field (see doc/zisofs_format.txt).
+ *
+ * @return
+ *      1 on success, < 0 on error
+ */
+int read_zisofs_ZF(struct susp_sys_user_entry *zf, uint8_t algorithm[2],
+                   uint8_t *header_size_div4, uint8_t *block_size_log2,
+                   uint32_t *uncompressed_size, int flag);
 
 #endif /* LIBISO_ROCKRIDGE_H */
