@@ -435,6 +435,8 @@ int read_rr_PN(struct susp_sys_user_entry *pn, struct stat *st)
 }
 
 
+/* AA is the field signature of AAIP versions < 2.0
+*/
 int read_aaip_AA(struct susp_sys_user_entry *sue,
                  unsigned char **aa_string, size_t *aa_size, size_t *aa_len,
                  size_t *prev_field, int *is_done, int flag)
@@ -442,9 +444,93 @@ int read_aaip_AA(struct susp_sys_user_entry *sue,
      unsigned char *aapt;
 
      if (*is_done) {
+
+         /* To coexist with Apple ISO :
+            Gracefully react on eventually trailing Apple AA
+         */
+         if (sue->version[0] != 1 || sue->len_sue[0] == 7)
+             return ISO_SUCCESS;
+
          return ISO_WRONG_RR;
      }
 
+
+     /* Eventually create or grow storage */
+     if (*aa_size == 0 || *aa_string == NULL) {
+
+         /* Gracefully react on eventually leading Apple AA
+         */
+         if (sue->version[0] != 1 || sue->len_sue[0] < 9) {
+             return ISO_SUCCESS;
+         }
+
+         *aa_size = *aa_len + sue->len_sue[0];
+         *aa_string = calloc(*aa_size, 1);
+         *aa_len = 0;
+     } else if (*aa_len + sue->len_sue[0] > *aa_size) {
+
+         if (sue->version[0] != 1) {
+             /* Apple ISO within the AAIP field group is not AAIP compliant
+             */
+             return ISO_WRONG_RR;
+         }
+
+         *aa_size += *aa_len + sue->len_sue[0];
+         *aa_string = realloc(*aa_string, *aa_size);
+     }
+     if (*aa_string == NULL)
+         return ISO_OUT_OF_MEM;
+
+     if (*aa_len > 0) {
+         /* Mark prev_field as being continued */
+         (*aa_string)[*prev_field + 4] = 1;
+     }
+
+     *prev_field = *aa_len;
+
+     /* Compose new SUSP header with signature aa[], cont == 0 */
+     aapt = *aa_string + *aa_len;
+
+     aapt[0] = 'A';
+
+#ifdef Libisofs_aaip_2_0
+     aapt[1] = 'L';
+#else /* Libisofs_aaip_2_0 */
+     aapt[1] = 'A';
+#endif /* ! Libisofs_aaip_2_0 */
+
+     aapt[2] = sue->len_sue[0];
+     aapt[3] = 1;
+     aapt[4] = 0;
+     /* Append sue payload */
+
+#ifdef Libisofs_aaip_2_0
+     memcpy(aapt + 5, sue->data.AL.comps, sue->len_sue[0] - 5);
+     *is_done = !(sue->data.AL.flags[0] & 1);
+#else /* Libisofs_aaip_2_0 */
+     memcpy(aapt + 5, sue->data.AA.comps, sue->len_sue[0] - 5);
+     *is_done = !(sue->data.AA.flags[0] & 1);
+#endif /* ! Libisofs_aaip_2_0 */
+
+     *aa_len += sue->len_sue[0];
+
+     return ISO_SUCCESS;
+}
+
+
+/* AL is the obsolete field signature of AAIP versions >= 2.0
+*/
+int read_aaip_AL(struct susp_sys_user_entry *sue,
+                 unsigned char **aa_string, size_t *aa_size, size_t *aa_len,
+                 size_t *prev_field, int *is_done, int flag)
+{
+     unsigned char *aapt;
+
+     if (*is_done)
+         return ISO_WRONG_RR;
+     if (sue->version[0] != 1)
+         return ISO_WRONG_RR;
+
      /* Eventually create or grow storage */
      if (*aa_size == 0 || *aa_string == NULL) {
          *aa_size = *aa_len + sue->len_sue[0];
@@ -466,17 +552,58 @@ int read_aaip_AA(struct susp_sys_user_entry *sue,
 
      /* Compose new SUSP header with signature aa[], cont == 0 */
      aapt = *aa_string + *aa_len;
+
      aapt[0] = 'A';
+
+#ifdef Libisofs_aaip_2_0
+     aapt[1] = 'L';
+#else /* Libisofs_aaip_2_0 */
      aapt[1] = 'A';
+#endif /* ! Libisofs_aaip_2_0 */
+
      aapt[2] = sue->len_sue[0];
      aapt[3] = 1;
      aapt[4] = 0;
      /* Append sue payload */
+
+#ifdef Libisofs_aaip_2_0
+     memcpy(aapt + 5, sue->data.AL.comps, sue->len_sue[0] - 5);
+     *is_done = !(sue->data.AL.flags[0] & 1);
+#else /* Libisofs_aaip_2_0 */
      memcpy(aapt + 5, sue->data.AA.comps, sue->len_sue[0] - 5);
+     *is_done = !(sue->data.AA.flags[0] & 1);
+#endif /* ! Libisofs_aaip_2_0 */
 
      *aa_len += sue->len_sue[0];
-     *is_done = !(sue->data.AA.flags[0] & 1);
 
      return ISO_SUCCESS;
 }
 
+/**
+ * Reads the zisofs parameters from a ZF field (see doc/zisofs_format.txt).
+ * 
+ * @return 
+ *      1 on success, < 0 on error
+ */
+int read_zisofs_ZF(struct susp_sys_user_entry *zf, uint8_t algorithm[2],
+                   uint8_t *header_size_div4, uint8_t *block_size_log2,
+                   uint32_t *uncompressed_size, int flag)
+{
+    if (zf == NULL) {
+        return ISO_NULL_POINTER;
+    }
+    if (zf->sig[0] != 'Z' || zf->sig[1] != 'F') {
+        return ISO_WRONG_ARG_VALUE;
+    }
+    if (zf->len_sue[0] != 16) {
+        return ISO_WRONG_RR;
+    }
+    algorithm[0] = zf->data.ZF.parameters[0];
+    algorithm[1] = zf->data.ZF.parameters[1];
+    *header_size_div4 = zf->data.ZF.parameters[2];
+    *block_size_log2 = zf->data.ZF.parameters[3];
+    *uncompressed_size = iso_read_bb(&(zf->data.ZF.parameters[4]), 4, NULL);
+    return ISO_SUCCESS;
+}
+
+
