@@ -191,15 +191,17 @@ int strconv(const char *str, const char *icharset, const char *ocharset,
     iconv_t conv;
 #endif
 
-    char *out;
+    char *out = NULL;
     char *src;
     char *ret;
+    int retval;
 
     inbytes = strlen(str);
     outbytes = (inbytes + 1) * MB_LEN_MAX;
-    out = alloca(outbytes);
+    out = calloc(outbytes, 1);
     if (out == NULL) {
-        return ISO_OUT_OF_MEM;
+        retval = ISO_OUT_OF_MEM;
+        goto ex;
     }
 
 #ifdef Libisofs_with_iso_iconV
@@ -210,7 +212,8 @@ int strconv(const char *str, const char *icharset, const char *ocharset,
     if (conv == (iconv_t)(-1)) {
 #endif
 
-        return ISO_CHARSET_CONV_ERROR;
+        retval = ISO_CHARSET_CONV_ERROR;
+        goto ex;
     }
 
     src = (char *)str;
@@ -228,7 +231,8 @@ int strconv(const char *str, const char *icharset, const char *ocharset,
         iconv_close(conv);
 #endif
 
-        return ISO_CHARSET_CONV_ERROR;
+        retval = ISO_CHARSET_CONV_ERROR;
+        goto ex;
     }
     *ret = '\0';
 
@@ -240,10 +244,15 @@ int strconv(const char *str, const char *icharset, const char *ocharset,
 
     *output = malloc(ret - out + 1);
     if (*output == NULL) {
-        return ISO_OUT_OF_MEM;
+        retval = ISO_OUT_OF_MEM;
+        goto ex;
     }
     memcpy(*output, out, ret - out + 1);
-    return ISO_SUCCESS;
+    retval = ISO_SUCCESS;
+ex:;
+    if (out != NULL)
+        free(out);
+    return retval;
 }
 
 int strnconv(const char *str, const char *icharset, const char *ocharset,
@@ -260,15 +269,17 @@ int strnconv(const char *str, const char *icharset, const char *ocharset,
     iconv_t conv;
 #endif
 
-    char *out;
+    char *out = NULL;
     char *src;
     char *ret;
+    int retval;
 
     inbytes = len;
     outbytes = (inbytes + 1) * MB_LEN_MAX;
-    out = alloca(outbytes);
+    out = calloc(outbytes, 1);
     if (out == NULL) {
-        return ISO_OUT_OF_MEM;
+        retval = ISO_OUT_OF_MEM;
+        goto ex;
     }
 
 #ifdef Libisofs_with_iso_iconV
@@ -279,7 +290,8 @@ int strnconv(const char *str, const char *icharset, const char *ocharset,
     if (conv == (iconv_t)(-1)) {
 #endif
 
-        return ISO_CHARSET_CONV_ERROR;
+        retval = ISO_CHARSET_CONV_ERROR;
+        goto ex;
     }
     src = (char *)str;
     ret = (char *)out;
@@ -296,7 +308,8 @@ int strnconv(const char *str, const char *icharset, const char *ocharset,
         iconv_close(conv);
 #endif
 
-        return ISO_CHARSET_CONV_ERROR;
+        retval = ISO_CHARSET_CONV_ERROR;
+        goto ex;
     }
     *ret = '\0';
 
@@ -308,10 +321,15 @@ int strnconv(const char *str, const char *icharset, const char *ocharset,
 
     *output = malloc(ret - out + 1);
     if (*output == NULL) {
-        return ISO_OUT_OF_MEM;
+        retval = ISO_OUT_OF_MEM;
+        goto ex;
     }
     memcpy(*output, out, ret - out + 1);
-    return ISO_SUCCESS;
+    retval = ISO_SUCCESS;
+ex:;
+    if (out != NULL)
+        free(out);
+    return retval;
 }
 
 /**
@@ -332,7 +350,7 @@ int str2wchar(const char *icharset, const char *input, wchar_t **output)
     iconv_t conv;
 #endif
 
-    /* ts A90308 : that while loop smells like a potential show stopper */
+    /* That while loop smells like a potential show stopper */
     size_t loop_counter = 0, loop_limit = 3;
 
     size_t inbytes;
@@ -453,10 +471,10 @@ int str2ascii(const char *icharset, const char *input, char **output)
     iconv_t conv;
 #endif
 
-    /* ts A90308 : that while loop smells like a potential show stopper */
+    /* That while loop smells like a potential show stopper */
     size_t loop_counter = 0, loop_limit = 3;
 
-    /* ts A90308 : fallback in case that iconv() is too demanding for system */
+    /* Fallback in case that iconv() is too demanding for system */
     unsigned char *cpt;
 
     size_t numchars;
@@ -618,7 +636,7 @@ int str2ucs(const char *icharset, const char *input, uint16_t **output)
     iconv_t conv;
 #endif
     
-    /* ts A90308 : that while loop smells like a potential show stopper */
+    /* That while loop smells like a potential show stopper */
     size_t loop_counter = 0, loop_limit = 3;
 
     size_t numchars;
@@ -932,12 +950,16 @@ char *iso_r_dirid(const char *src, int size, int relaxed)
  */
 char *iso_r_fileid(const char *src, size_t len, int relaxed, int forcedot)
 {
-    char *dot;
+    char *dot, *retval = NULL;
     int lname, lext, lnname, lnext, pos, i;
-    char *dest = alloca(len + 1 + 1);
+    char *dest = NULL;
+
+    dest = calloc(len + 1 + 1, 1);
+    if (dest == NULL)
+        goto ex;
 
     if (src == NULL) {
-        return NULL;
+        goto ex;
     }
 
     dot = strrchr(src, '.');
@@ -962,7 +984,7 @@ char *iso_r_fileid(const char *src, size_t len, int relaxed, int forcedot)
     }
 
     if (lnname == 0 && lnext == 0) {
-        return NULL;
+        goto ex;
     }
 
     pos = 0;
@@ -1018,7 +1040,13 @@ char *iso_r_fileid(const char *src, size_t len, int relaxed, int forcedot)
         }
     }
     dest[pos] = '\0';
-    return strdup(dest);
+
+    retval = strdup(dest);
+
+ex:;
+    if (dest != NULL)
+        free(dest);
+    return retval;
 }
 
 uint16_t *iso_j_file_id(const uint16_t *src)
@@ -1537,7 +1565,7 @@ void strncpy_pad(char *dest, const char *src, size_t max)
 char *ucs2str(const char *buf, size_t len)
 {
     size_t outbytes, inbytes;
-    char *str, *src, *out;
+    char *str, *src, *out = NULL, *retval = NULL;
 
 #ifdef Libisofs_with_iso_iconV
     struct iso_iconv_handle conv;
@@ -1553,14 +1581,16 @@ char *ucs2str(const char *buf, size_t len)
     outbytes = (inbytes+1) * MB_LEN_MAX;
     
     /* ensure enought space */
-    out = alloca(outbytes);
+    out = calloc(outbytes, 1);
 
     /* convert to local charset */
 
+#ifndef Libisofs_setlocale_in_iniT
     /* ??? ts Nov 25 2008 :
        Shouldn't this go to library initialization or even to app ?
     */
     setlocale(LC_CTYPE, "");
+#endif
 
 #ifdef Libisofs_with_iso_iconV
     conv_ret = iso_iconv_open(&conv, iso_get_local_charset(0), "UCS-2BE", 0);
@@ -1570,7 +1600,7 @@ char *ucs2str(const char *buf, size_t len)
     if (conv == (iconv_t)(-1)) {
 #endif
 
-        return NULL;
+        goto ex;
     }
     src = (char *)buf;
     str = (char *)out;
@@ -1586,14 +1616,20 @@ char *ucs2str(const char *buf, size_t len)
 
     if (n == -1) {
         /* error */
-        return NULL;
+        goto ex;
     }
     *str = '\0';
 
     /* remove trailing spaces */
     for (len = strlen(out) - 1; out[len] == ' ' && len > 0; --len)
         out[len] = '\0';
-    return strdup(out);
+
+    retval = strdup(out);
+
+ex:;
+    if (out != NULL)
+        free(out);
+    return retval;
 }
 
 void iso_lib_version(int *major, int *minor, int *micro)
@@ -1617,3 +1653,10 @@ int iso_lib_is_compatible(int major, int minor, int micro)
                    || (cminor == minor && cmicro >= micro)));
 }
 
+int iso_init_locale(int flag)
+{
+    setlocale(LC_CTYPE, "");
+    return 1;
+}
+
+
